@@ -1,20 +1,22 @@
+from typing import List  # noqa
 
-class SwitchState(object):
+
+class SwitchState:
     ON = True
     OFF = False
 
     @staticmethod
     def to_state(string):
-        return SwitchState.ON if string == "ON" else SwitchState.OFF
+        return SwitchState.ON if string == 'ON' else SwitchState.OFF
 
     @staticmethod
     def to_string(state):
-        return "ON" if state else "OFF"
+        return 'ON' if state else 'OFF'
 
 
-class Switch(object):
+class Switch:
 
-    switches = []
+    switches = []  # type: List[Switch]
 
     def __init__(self, name, title=None, description=None, state=SwitchState.ON):
 
@@ -33,11 +35,11 @@ class Switch(object):
             'type': 'text',
             'title': self.title,
             'description': self.description,
-            'value': "ON" if self.is_on else "OFF",
+            'value': 'ON' if self.is_on else 'OFF',
         }
 
     def __repr__(self):
-        return 'Switch(name=%r, description=%r, state=%r)' % (
+        return 'Switch(name={!r}, description={!r}, state={!r})'.format(
             self.name, self.description, SwitchState.to_string(self.state)
         )
 
